@@ -12,6 +12,15 @@ improved performance in I/O-bound operations.
 automatically cache duplicate inputs within each partition, significantly reducing
 API calls and costs when processing datasets with overlapping content.
 
+__all__ = [
+    "count_tokens_udf",
+    "embeddings_udf",
+    "responses_udf",
+    "similarity_udf",
+    "split_to_chunks_udf",
+    "task_udf",
+]
+
 ## Setup
 
 First, obtain a Spark session and configure authentication:
@@ -115,7 +124,7 @@ Note: This module provides asynchronous support through the pandas extensions.
 import asyncio
 import logging
 from enum import Enum
-from typing import Dict, Iterator, List, Optional, Type, Union, get_args, get_origin
+from typing import Dict, Iterator, List, Type, Union, get_args, get_origin
 
 import numpy as np
 import pandas as pd
@@ -127,10 +136,10 @@ from pyspark.sql.udf import UserDefinedFunction
 from typing_extensions import Literal
 
 from openaivec import pandas_ext
-from openaivec.model import PreparedTask, ResponseFormat
-from openaivec.proxy import AsyncBatchingMapProxy
-from openaivec.serialize import deserialize_base_model, serialize_base_model
-from openaivec.util import TextChunker
+from openaivec._model import PreparedTask, ResponseFormat
+from openaivec._proxy import AsyncBatchingMapProxy
+from openaivec._serialize import deserialize_base_model, serialize_base_model
+from openaivec._util import TextChunker
 
 __all__ = [
     "responses_udf",
@@ -198,7 +207,7 @@ def _pydantic_to_spark_schema(model: Type[BaseModel]) -> StructType:
     return StructType(fields)
 
 
-def _safe_cast_str(x: Optional[str]) -> Optional[str]:
+def _safe_cast_str(x: str | None) -> str | None:
     try:
         if x is None:
             return None
@@ -209,7 +218,7 @@ def _safe_cast_str(x: Optional[str]) -> Optional[str]:
         return None
 
 
-def _safe_dump(x: Optional[BaseModel]) -> Dict:
+def _safe_dump(x: BaseModel | None) -> Dict:
     try:
         if x is None:
             return {}
@@ -224,10 +233,11 @@ def responses_udf(
     instructions: str,
     response_format: Type[ResponseFormat] = str,
     model_name: str = "gpt-4.1-mini",
-    batch_size: int = 128,
+    batch_size: int | None = None,
     temperature: float | None = 0.0,
     top_p: float = 1.0,
     max_concurrency: int = 8,
+    **api_kwargs,
 ) -> UserDefinedFunction:
     """Create an asynchronous Spark pandas UDF for generating responses.
 
@@ -255,9 +265,11 @@ def responses_udf(
             or a Pydantic `BaseModel` for structured JSON output. Defaults to `str`.
         model_name (str): For Azure OpenAI, use your deployment name (e.g., "my-gpt4-deployment").
             For OpenAI, use the model name (e.g., "gpt-4.1-mini"). Defaults to "gpt-4.1-mini".
-        batch_size (int): Number of rows per async batch request within each partition.
+        batch_size (int | None): Number of rows per async batch request within each partition.
             Larger values reduce API call overhead but increase memory usage.
-            Recommended: 32-128 depending on data complexity. Defaults to 128.
+            Defaults to None (automatic batch size optimization that dynamically
+            adjusts based on execution time, targeting 30-60 seconds per batch).
+            Set to a positive integer (e.g., 32-128) for fixed batch size.
         temperature (float): Sampling temperature (0.0 to 2.0). Defaults to 0.0.
         top_p (float): Nucleus sampling parameter. Defaults to 1.0.
         max_concurrency (int): Maximum number of concurrent API requests **PER EXECUTOR**.
@@ -265,6 +277,11 @@ def responses_udf(
             Higher values increase throughput but may hit OpenAI rate limits.
             Recommended: 4-12 per executor. Defaults to 8.
 
+    Additional Keyword Args:
+        Arbitrary OpenAI Responses API parameters (e.g. ``frequency_penalty``, ``presence_penalty``,
+        ``seed``, ``max_output_tokens``, etc.) are forwarded verbatim to the underlying API calls.
+        These parameters are applied to all API requests made by the UDF.
+
     Returns:
         UserDefinedFunction: A Spark pandas UDF configured to generate responses asynchronously.
             Output schema is `StringType` or a struct derived from `response_format`.
@@ -284,7 +301,7 @@ def responses_udf(
         spark_schema = _pydantic_to_spark_schema(response_format)
         json_schema_string = serialize_base_model(response_format)
 
-        @pandas_udf(returnType=spark_schema)
+        @pandas_udf(returnType=spark_schema)  # type: ignore[call-overload]
         def structure_udf(col: Iterator[pd.Series]) -> Iterator[pd.DataFrame]:
             pandas_ext.responses_model(model_name)
             response_format = deserialize_base_model(json_schema_string)
@@ -302,17 +319,18 @@ def responses_udf(
                             temperature=temperature,
                             top_p=top_p,
                             cache=cache,
+                            **api_kwargs,
                         )
                     )
                     yield pd.DataFrame(predictions.map(_safe_dump).tolist())
             finally:
-                cache.clear()
+                asyncio.run(cache.clear())
 
-        return structure_udf
+        return structure_udf  # type: ignore[return-value]
 
     elif issubclass(response_format, str):
 
-        @pandas_udf(returnType=StringType())
+        @pandas_udf(returnType=StringType())  # type: ignore[call-overload]
         def string_udf(col: Iterator[pd.Series]) -> Iterator[pd.Series]:
             pandas_ext.responses_model(model_name)
             cache = AsyncBatchingMapProxy[str, str](
@@ -329,23 +347,25 @@ def responses_udf(
                             temperature=temperature,
                             top_p=top_p,
                             cache=cache,
+                            **api_kwargs,
                         )
                     )
                     yield predictions.map(_safe_cast_str)
             finally:
-                cache.clear()
+                asyncio.run(cache.clear())
 
-        return string_udf
+        return string_udf  # type: ignore[return-value]
 
     else:
         raise ValueError(f"Unsupported response_format: {response_format}")
 
 
 def task_udf(
-    task: PreparedTask,
+    task: PreparedTask[ResponseFormat],
     model_name: str = "gpt-4.1-mini",
-    batch_size: int = 128,
+    batch_size: int | None = None,
     max_concurrency: int = 8,
+    **api_kwargs,
 ) -> UserDefinedFunction:
     """Create an asynchronous Spark pandas UDF from a predefined task.
 
@@ -360,14 +380,22 @@ def task_udf(
             response format, temperature, and top_p settings.
         model_name (str): For Azure OpenAI, use your deployment name (e.g., "my-gpt4-deployment").
             For OpenAI, use the model name (e.g., "gpt-4.1-mini"). Defaults to "gpt-4.1-mini".
-        batch_size (int): Number of rows per async batch request within each partition.
+        batch_size (int | None): Number of rows per async batch request within each partition.
             Larger values reduce API call overhead but increase memory usage.
-            Recommended: 32-128 depending on task complexity. Defaults to 128.
+            Defaults to None (automatic batch size optimization that dynamically
+            adjusts based on execution time, targeting 30-60 seconds per batch).
+            Set to a positive integer (e.g., 32-128) for fixed batch size.
         max_concurrency (int): Maximum number of concurrent API requests **PER EXECUTOR**.
             Total cluster concurrency = max_concurrency × number_of_executors.
             Higher values increase throughput but may hit OpenAI rate limits.
             Recommended: 4-12 per executor. Defaults to 8.
 
+    Additional Keyword Args:
+        Arbitrary OpenAI Responses API parameters (e.g. ``frequency_penalty``, ``presence_penalty``,
+        ``seed``, ``max_output_tokens``, etc.) are forwarded verbatim to the underlying API calls.
+        These parameters are applied to all API requests made by the UDF and override any
+        parameters set in the task configuration.
+
     Returns:
         UserDefinedFunction: A Spark pandas UDF configured to execute the specified task
             asynchronously with automatic caching for duplicate inputs within each partition.
@@ -399,7 +427,7 @@ def task_udf(
         response_format = deserialize_base_model(task_response_format_json)
         spark_schema = _pydantic_to_spark_schema(response_format)
 
-        @pandas_udf(returnType=spark_schema)
+        @pandas_udf(returnType=spark_schema)  # type: ignore[call-overload]
         def task_udf(col: Iterator[pd.Series]) -> Iterator[pd.DataFrame]:
             pandas_ext.responses_model(model_name)
             cache = AsyncBatchingMapProxy[str, response_format](
@@ -416,17 +444,18 @@ def task_udf(
                             temperature=task_temperature,
                             top_p=task_top_p,
                             cache=cache,
+                            **api_kwargs,
                         )
                     )
                     yield pd.DataFrame(predictions.map(_safe_dump).tolist())
             finally:
-                cache.clear()
+                asyncio.run(cache.clear())
 
-        return task_udf
+        return task_udf  # type: ignore[return-value]
 
     elif issubclass(task.response_format, str):
 
-        @pandas_udf(returnType=StringType())
+        @pandas_udf(returnType=StringType())  # type: ignore[call-overload]
         def task_string_udf(col: Iterator[pd.Series]) -> Iterator[pd.Series]:
             pandas_ext.responses_model(model_name)
             cache = AsyncBatchingMapProxy[str, str](
@@ -443,20 +472,21 @@ def task_udf(
                             temperature=task_temperature,
                             top_p=task_top_p,
                             cache=cache,
+                            **api_kwargs,
                         )
                     )
                     yield predictions.map(_safe_cast_str)
             finally:
-                cache.clear()
+                asyncio.run(cache.clear())
 
-        return task_string_udf
+        return task_string_udf  # type: ignore[return-value]
 
     else:
         raise ValueError(f"Unsupported response_format in task: {task.response_format}")
 
 
 def embeddings_udf(
-    model_name: str = "text-embedding-3-small", batch_size: int = 128, max_concurrency: int = 8
+    model_name: str = "text-embedding-3-small", batch_size: int | None = None, max_concurrency: int = 8
 ) -> UserDefinedFunction:
     """Create an asynchronous Spark pandas UDF for generating embeddings.
 
@@ -481,10 +511,12 @@ def embeddings_udf(
     Args:
         model_name (str): For Azure OpenAI, use your deployment name (e.g., "my-embedding-deployment").
             For OpenAI, use the model name (e.g., "text-embedding-3-small"). Defaults to "text-embedding-3-small".
-        batch_size (int): Number of rows per async batch request within each partition.
+        batch_size (int | None): Number of rows per async batch request within each partition.
             Larger values reduce API call overhead but increase memory usage.
+            Defaults to None (automatic batch size optimization that dynamically
+            adjusts based on execution time, targeting 30-60 seconds per batch).
+            Set to a positive integer (e.g., 64-256) for fixed batch size.
             Embeddings typically handle larger batches efficiently.
-            Recommended: 64-256 depending on text length. Defaults to 128.
         max_concurrency (int): Maximum number of concurrent API requests **PER EXECUTOR**.
             Total cluster concurrency = max_concurrency × number_of_executors.
             Higher values increase throughput but may hit OpenAI rate limits.
@@ -505,7 +537,7 @@ def embeddings_udf(
         - Use larger batch_size for embeddings compared to response generation
     """
 
-    @pandas_udf(returnType=ArrayType(FloatType()))
+    @pandas_udf(returnType=ArrayType(FloatType()))  # type: ignore[call-overload,misc]
     def _embeddings_udf(col: Iterator[pd.Series]) -> Iterator[pd.Series]:
         pandas_ext.embeddings_model(model_name)
         cache = AsyncBatchingMapProxy[str, np.ndarray](
@@ -518,9 +550,9 @@ def embeddings_udf(
                 embeddings: pd.Series = asyncio.run(part.aio.embeddings_with_cache(cache=cache))
                 yield embeddings.map(lambda x: x.tolist())
         finally:
-            cache.clear()
+            asyncio.run(cache.clear())
 
-    return _embeddings_udf
+    return _embeddings_udf  # type: ignore[return-value]
 
 
 def split_to_chunks_udf(max_tokens: int, sep: List[str]) -> UserDefinedFunction:
@@ -535,7 +567,7 @@ def split_to_chunks_udf(max_tokens: int, sep: List[str]) -> UserDefinedFunction:
             values are lists of chunks respecting the ``max_tokens`` limit.
     """
 
-    @pandas_udf(ArrayType(StringType()))
+    @pandas_udf(ArrayType(StringType()))  # type: ignore[call-overload,misc]
     def fn(col: Iterator[pd.Series]) -> Iterator[pd.Series]:
         encoding = tiktoken.get_encoding("o200k_base")
         chunker = TextChunker(encoding)
@@ -543,7 +575,7 @@ def split_to_chunks_udf(max_tokens: int, sep: List[str]) -> UserDefinedFunction:
         for part in col:
             yield part.map(lambda x: chunker.split(x, max_tokens=max_tokens, sep=sep) if isinstance(x, str) else [])
 
-    return fn
+    return fn  # type: ignore[return-value]
 
 
 def count_tokens_udf() -> UserDefinedFunction:
@@ -556,18 +588,18 @@ def count_tokens_udf() -> UserDefinedFunction:
         A pandas UDF producing an ``IntegerType`` column with token counts.
     """
 
-    @pandas_udf(IntegerType())
+    @pandas_udf(IntegerType())  # type: ignore[call-overload]
     def fn(col: Iterator[pd.Series]) -> Iterator[pd.Series]:
         encoding = tiktoken.get_encoding("o200k_base")
 
         for part in col:
             yield part.map(lambda x: len(encoding.encode(x)) if isinstance(x, str) else 0)
 
-    return fn
+    return fn  # type: ignore[return-value]
 
 
 def similarity_udf() -> UserDefinedFunction:
-    @pandas_udf(FloatType())
+    @pandas_udf(FloatType())  # type: ignore[call-overload]
     def fn(a: pd.Series, b: pd.Series) -> pd.Series:
         """Compute cosine similarity between two vectors.
 
@@ -579,8 +611,11 @@ def similarity_udf() -> UserDefinedFunction:
             Cosine similarity between the two vectors.
         """
         # Import pandas_ext to ensure .ai accessor is available in Spark workers
-        from openaivec import pandas_ext  # noqa: F401
+        from openaivec import pandas_ext
+
+        # Explicitly reference pandas_ext to satisfy linters
+        assert pandas_ext is not None
 
         return pd.DataFrame({"a": a, "b": b}).ai.similarity("a", "b")
 
-    return fn
+    return fn  # type: ignore[return-value]
