@@ -8,7 +8,7 @@ Example:
 
     ```python
     from openai import OpenAI
-    from openaivec.responses import BatchResponses
+    from openaivec._responses import BatchResponses
     from openaivec.task import nlp
 
     client = OpenAI()
@@ -50,11 +50,11 @@ Attributes:
         top_p=1.0 for deterministic output.
 """
 
-from typing import List, Optional
+from typing import List
 
 from pydantic import BaseModel, Field
 
-from openaivec.model import PreparedTask
+from openaivec._model import PreparedTask
 
 __all__ = ["KEYWORD_EXTRACTION"]
 
@@ -63,7 +63,7 @@ class Keyword(BaseModel):
     text: str = Field(description="The keyword or phrase")
     score: float = Field(description="Importance score (0.0-1.0)")
     frequency: int = Field(description="Frequency of occurrence in the text")
-    context: Optional[str] = Field(description="Context where the keyword appears")
+    context: str | None = Field(description="Context where the keyword appears")
 
 
 class KeywordExtraction(BaseModel):
